@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2017,2019-2020 Aurimas Cernius
+ * Copyright (C) 2010-2017,2019-2021 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -99,14 +99,23 @@ namespace gnote {
    }
 
 
-    void popup_menu(Gtk::Menu &menu, const GdkEventButton * ev)
+    void popup_menu(Gtk::Menu &menu, const GdkEventButton *ev)
     {
+      guint button = 0;
+      guint32 time;
+      auto event = (const GdkEvent*)ev;
+      if(event) {
+        gdk_event_get_button(event, &button);
+        time = gdk_event_get_time(event);
+      }
+      else {
+        time = gtk_get_current_event_time();
+      }
       menu.signal_deactivate().connect(sigc::bind(&deactivate_menu, &menu));
       menu.popup([&menu](int & x, int & y, bool & push_in) {
                    get_menu_position(&menu, x, y, push_in);
                   },
-                 (ev ? ev->button : 0), 
-                 (ev ? ev->time : gtk_get_current_event_time()));
+                 button, time);
       if(menu.get_attach_widget()) {
         menu.get_attach_widget()->set_state(Gtk::STATE_SELECTED);
       }
@@ -175,8 +184,7 @@ namespace gnote {
     {
       bool use_12h = false;
       if(show_time) {
-        use_12h = preferences.get_schema_settings(Preferences::SCHEMA_DESKTOP_GNOME_INTERFACE)->get_string(
-            Preferences::DESKTOP_GNOME_CLOCK_FORMAT) == "12h";
+        use_12h = preferences.desktop_gnome_clock_format() == "12h";
       }
       return get_pretty_print_date(date, show_time, use_12h);
     }
@@ -274,7 +282,7 @@ namespace gnote {
     }
 
 
-    void GlobalKeybinder::add_accelerator(const sigc::slot<void> & handler, guint key, 
+    void* GlobalKeybinder::add_accelerator(const sigc::slot<void> & handler, guint key,
                                           Gdk::ModifierType modifiers, Gtk::AccelFlags flags)
     {
       Gtk::MenuItem *foo = manage(new Gtk::MenuItem ());
@@ -287,6 +295,14 @@ namespace gnote {
       foo->show ();
       foo->set_sensitive(m_fake_menu.get_sensitive());
       m_fake_menu.append (*foo);
+      return foo;
+    }
+
+    void GlobalKeybinder::remove_accelerator(void *accel)
+    {
+      auto widget = static_cast<Gtk::Widget*>(accel);
+      m_fake_menu.remove(*widget);
+      delete widget;
     }
 
     void GlobalKeybinder::enabled(bool enable)
